import { ApiFetchConfig, ApiGetConfig, ApiPageResponse, ApiParamType, ApiPostConfig, ApiResponse, ApiUploadConfig, Pageable, Sortable } from './types';
/**
 * fetch函数
 * @param param 请求配置信息
 * @returns Promise对象
 */
export declare const fetch: <Type>({ url, method, headers, params, data, contentType, responseType, timeout, onProgress, baseURL }: ApiFetchConfig) => Promise<Type>;
/**
 * 上传函数
 * @param config 请求配置信息
 * @returns Promise对象
 */
export declare const upload: <Type>(config: ApiUploadConfig) => Promise<ApiResponse<Type>>;
/**
 * Json Get函数
 * @param config 请求配置信息
 * @returns
 */
export declare const get: <Type>(config: ApiGetConfig) => Promise<ApiResponse<Type>>;
/**
 * Post函数
 * @param config 请求配置信息
 * @returns
 */
export declare const post: <Type>(config: ApiPostConfig) => Promise<ApiResponse<Type>>;
/**
 * 分页Get函数
 * @param config 请求配置信息
 * @returns
 */
export declare const getPage: <Type>(config: ApiGetConfig & {
    page: Pageable;
    sort?: Sortable;
}) => Promise<ApiPageResponse<Type>>;
/**
 * 分页Post函数
 * @param config 请求配置信息
 * @returns
 */
export declare const postPage: <Type>(config: ApiPostConfig & {
    page: Pageable;
    sort?: Sortable;
}) => Promise<ApiPageResponse<Type>>;
/**
 * 定义一个Upload函数
 * @param <R> 返回类型
 * @param <T> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个请求函数
 */
export declare const defineUploadApi: <R = any, T = ApiParamType>(config: Omit<ApiUploadConfig, 'params' | 'data'>, defaultParam?: Partial<T>) => (data: FormData, params?: T, onProgress?: ApiUploadConfig['onProgress']) => Promise<ApiResponse<R>>;
/**
 * 定义一个Get函数
 * @param <R> 返回类型
 * @param <D> Form数据的类型
 * @param <T> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个请求函数
 */
export declare const defineGetApi: <R = any, T = ApiParamType>(config: Omit<ApiGetConfig, 'params'>, defaultParam?: Partial<T>) => (params?: T) => Promise<ApiResponse<R>>;
/**
 * 定义一个分页Get函数
 * @param <R> 返回类型
 * @param <T> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个分页请求函数
 */
export declare const defineGetPageApi: <R = any, T = ApiParamType>(config: Omit<ApiGetConfig, 'params'>, defaultParam?: Partial<T>) => (params: T, page: Pageable, sort?: Sortable) => Promise<ApiPageResponse<R>>;
/**
 * 定义一个Post函数
 * @param <R> 返回类型
 * @param <D> Post数据的类型
 * @param <T> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个请求函数
 */
export declare const definePostApi: <R = any, D = ApiParamType, T = ApiParamType>(config: Omit<ApiPostConfig, 'params' | 'data'>, defaultParam?: Partial<T>) => (data: D, params?: T) => Promise<ApiResponse<R>>;
/**
 * 定义一个分页Post函数
 * @param <R> 返回类型
 * @param <D> Post数据的类型
 * @param <T> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个分页请求函数
 */
export declare const definePostPageApi: <R, D = ApiParamType, T = ApiParamType>(config: Omit<ApiPostConfig, 'params' | 'data'>, defaultParam?: Partial<T>) => (data: D, page: Pageable, params?: T, sort?: Sortable) => Promise<ApiPageResponse<R>>;
